@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2022 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -24,9 +24,7 @@
 #ifndef _GROUPS_H_
 #define _GROUPS_H_
 
-#define GROUP_SELECT_ALL             0
-#define GROUP_SELECT_EWIN_ONLY       1
-#define GROUP_SELECT_ALL_EXCEPT_EWIN 2
+#include "etypes.h"
 
 /* For window group listing */
 #define GROUP_ACTION_ANY                     0
@@ -38,37 +36,20 @@
 #define GROUP_ACTION_SHADE                   6
 #define GROUP_ACTION_SET_WINDOW_BORDER       7
 
-typedef struct _groupconfig {
-   char                iconify;
-   char                kill;
-   char                move;
-   char                raise;
-   char                set_border;
-   char                shade;
-   char                stick;
-} GroupConfig;
-
-struct _group {
-   int                 index;
-   EWin              **members;
-   int                 num_members;
-   GroupConfig         cfg;
-   char                save;	/* Used in snapshot - must save */
-};
-
 /* finders.c */
-EWin              **ListWinGroupMembersForEwin(const EWin * ewin, int action,
-					       char nogroup, int *num);
+EWin          **ListWinGroupMembersForEwin(const EWin * ewin, int action,
+                                           char nogroup, int *num);
 
 /* groups.c */
-Group              *const *EwinGetGroups(const EWin * ewin, int *num);
-Group              *EwinsInGroup(const EWin * ewin1, const EWin * ewin2);
-void                GroupsEwinAdd(EWin * ewin, const int *pgid, int ngid);
-void                GroupsEwinRemove(EWin * ewin);
-void                GroupsLoad(void);
-void                GroupsSave(void);
-Group             **GroupsGetList(int *pnum);
-int                 GroupsGetSwapmove(void);
-void                GroupRemember(int gid);
+int             GroupMatchAction(const Group * g, int action);
+int             GroupGetIndex(const Group * g);
+void            GroupSetUsed(int gid);
+EWin           *const *GroupGetMembers(const Group * g, int *num);
+Group          *EwinsInGroup(const EWin * ewin1, const EWin * ewin2);
+void            GroupsEwinAdd(EWin * ewin, const int *pgid, int ngid);
+void            GroupsEwinRemove(EWin * ewin);
+void            GroupsLoad(void);
+void            GroupsPrune(void);
+Group         **GroupsGetList(int *pnum);
 
-#endif /* _GROUPS_H_ */
+#endif                          /* _GROUPS_H_ */
